==> dataprep-0.2.10a0.tar.gz: dataprep-0.2.10a0/dataprep/eda/create_report/__init__.py <==
"""
    This module implements the create_report(df) function.
"""

from typing import Optional
from pathlib import Path
import pandas as pd
from bokeh.resources import CDN
from jinja2 import Environment, PackageLoader, select_autoescape
from .formatter import format_report

__all__ = ["create_report"]

ENV_LOADER = Environment(
    loader=PackageLoader("dataprep", "eda/create_report/templates"),
)


def create_report(
    df: pd.DataFrame,
    title: Optional[str] = "DataPrep Report",
    mode: Optional[str] = "basic",
) -> None:
    """
    This function is to generate and render element in a report object.

    Parameters
    ----------
    df
        The DataFrame for which data are calculated.
    title: Optional[str], default "DataPrep Report"
        The title and the filename of the report.
    mode: Optional[str], default "basic"
        This controls what type of report to be generated.
        Currently only the 'basic' is fully implemented.

    Examples
    --------
    >>> import pandas as pd
    >>> from dataprep.eda import create_report
    >>> iris = pd.read_csv('https://raw.githubusercontent.com/mwaskom/seaborn-data/master/iris.csv')
    >>> create_report(iris)
    """
    context = {
        "cdn": CDN.render(),
        "title": title,
        "components": format_report(df, mode),
    }
    template_base = ENV_LOADER.get_template("base.html")
    with open(Path.cwd() / f"{title}.html", "w") as file:
        file.write(template_base.render(context=context))

==> dataprep-0.2.11.tar.gz: dataprep-0.2.11/dataprep/eda/create_report/__init__.py <==
"""
    This module implements the create_report(df) function.
"""

from typing import Optional
from pathlib import Path
import pandas as pd
from bokeh.resources import INLINE
from jinja2 import Environment, PackageLoader, select_autoescape
from .formatter import format_report
from .io import Report

__all__ = ["create_report"]

ENV_LOADER = Environment(
    loader=PackageLoader("dataprep", "eda/create_report/templates"),
)


def create_report(
    df: pd.DataFrame,
    title: Optional[str] = "DataPrep Report",
    mode: Optional[str] = "basic",
) -> Report:
    """
    This function is to generate and render element in a report object.

    Parameters
    ----------
    df
        The DataFrame for which data are calculated.
    title: Optional[str], default "DataPrep Report"
        The title of the report, which will be shown on the navigation bar.
    mode: Optional[str], default "basic"
        This controls what type of report to be generated.
        Currently only the 'basic' is fully implemented.

    Examples
    --------
    >>> import pandas as pd
    >>> from dataprep.eda import create_report
    >>> df = pd.read_csv('https://raw.githubusercontent.com/mwaskom/seaborn-data/master/iris.csv')
    >>> report = create_report(df)
    >>> report # show report in notebook
    >>> report.save('My Fantastic Report') # save report to local disk
    >>> report.show_browser() # show report in the browser
    """
    context = {
        "resources": INLINE.render(),
        "title": title,
        "components": format_report(df, mode),
    }
    template_base = ENV_LOADER.get_template("base.html")
    report = template_base.render(context=context)
    return Report(report)
